{% ckan_extends %}

{% block resource_item_title %}
    <a class="heading" href="#" title="{{ res.name or res.description }}">
        {{ h.resource_display_name(res) | truncate(50) }}<span class="format-label" property="dc:format" data-format="{{ res.format.lower() or 'data' }}">{{ h.get_translated(res, 'format') }}</span>
    </a>
{% endblock %}

{% block resource_item_explore %}

{% endblock  %}

